EntityDiff

Struct EntityDiff 

pub struct EntityDiff { /* private fields */ }
Performs a diff between two entities, and contains the resulting JSON for use in wbeditentity

Implementations

Source

impl EntityDiff

pub fn new(i1: &Entity, i2: &Entity, params: &EntityDiffParams) -> EntityDiff

Perform a diff, and return a new EntityDiff with the result

pub fn new_as_result( i1: &Entity, i2: &Entity, params: &EntityDiffParams, ) -> Result<EntityDiff, Vec<String>>

pub fn actions(&self) -> &Value

The JSON resulting from the diff, for use in wbeditentity

pub fn actions_mut(&mut self) -> &mut Value

The JSON resulting from the diff, for use in wbeditentity, as mutable

pub fn as_str(&self) -> Result<String, Error>

The JSON resulting from the diff, as a String

pub fn to_string_pretty(&self) -> Result<String, Error>

The JSON resulting from the diff, as a pretty (printable) String

pub fn edit_summary(&self) -> &Option<String>

pub fn set_edit_summary(&mut self, edit_summary: Option<String>)

pub fn is_empty(&self) -> bool

Checks if the result from the diff is empty (=> no action needs to be taken)

pub fn edit_target(&self) -> &EditTarget

Return the current edit target

pub fn set_edit_target(&mut self, edit_target: EditTarget)

Set the current edit target

pub async fn apply_diff( &self, mw_api: &mut Api, diff: &EntityDiff, ) -> Result<Value, WikibaseError>

Applied the diff to the Wikibase entity online, via wbeditentity

pub fn get_entity_id(entity_json: &Value) -> Option<String>

Returns the entity ID (String) from a JSON result. Intended to get the ID on a new entity, which is stored in the result of apply_diff