[−][src]Struct wikibase::SearchResultEntity
Search-result entity
Struct that holds all the data about a search result. The difference to a normal entity is that no claims and sitelinks are returned. The label, description and aliases are only returned for one language.
Methods
impl SearchResultEntity[src]
pub fn new<S: Into<String>>(
id: S,
entity_type: EntityType,
label: LocaleString,
description: Option<LocaleString>,
aliases: Vec<LocaleString>
) -> SearchResultEntity[src]
id: S,
entity_type: EntityType,
label: LocaleString,
description: Option<LocaleString>,
aliases: Vec<LocaleString>
) -> SearchResultEntity
pub fn aliases(&self) -> &Vec<LocaleString>[src]
pub fn description(&self) -> &Option<LocaleString>[src]
pub fn id(&self) -> &str[src]
pub fn label(&self) -> &LocaleString[src]
pub fn set_aliases(&mut self, aliases: Vec<LocaleString>)[src]
pub fn set_descriptions(&mut self, description: Option<LocaleString>)[src]
pub fn set_labels(&mut self, label: LocaleString)[src]