pub fn validate_user_agent(user_agent: &str) -> Result<String, WikibaseError>Expand description
Checks the validity of a user-agent string and returns a Result
If the user-agent string is valid, the Result contains the string.
pub fn validate_user_agent(user_agent: &str) -> Result<String, WikibaseError>Checks the validity of a user-agent string and returns a Result
If the user-agent string is valid, the Result contains the string.